---
title: 관리자콘솔의 계정 주소를 변경할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 관리자콘솔의 계정 주소를 변경할 수 있나요?
  description: 포트원 관리자콘솔 로그인 메일주소를 변경할 수 있는 방법 안내입니다. 로그인이 불가하신 경우에는 별도의 인증과정이 진행될 수 있습니다.
  keywords:
    - 관리자콘솔
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 메일주소변경
  - 관리자콘솔계정
  - 계정주소변경
  - 계정변경
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="로그인이 불가하신 경우 별도 인증과정이 진행될 수 있는 점 참고부탁드립니다." title="포트원 관리자콘솔 로그인 메일주소를 변경할 수 있는 방법을 안내드립니다." />

#### **관리자콘솔 로그인이 가능한 경우**

- [포트원 관리자콘솔 로그인↗](https://admin.portone.io/) > 설정 > 내 정보 관리 > 이메일 변경

<Callout content=" 포트원 관리자콘솔 내 한번도 가입된 적 없는 계정으로만 변경이 가능합니다." icon="❗" title="유의사항" />





#### **관리자콘솔 로그인이 불가한 경우**

[포트원 관리자콘솔↗](https://admin.portone.io/) > 비밀번호 재설정 > 메일로 비밀번호 재설정 링크 수신 후 변경가능





#### **관리자콘솔 로그인 & 메일 수신이 불가한 경우**

아래 정보를 포트원 고객지원팀(<cs@portone.io>)으로 전달하신 후 강제로 포트원 메일주소를 변경합니다. \
(변경된 메일주소로 비밀번호 재설정링크 수신하여 변경 가능합니다)

- 상호명 :
- 사업자번호 :
- 대표자명 :
- 대표자 생년월일 :
- 고객사 식별코드 :
- 이용하시는 결제대행사(PG사) / 상점아이디 :
